PastryNode

Struct PastryNode 

pub struct PastryNode { /* private fields */ }
An instance of a Pastry node.

Implementations

Source

impl PastryNode

pub fn new( config: Config, addr: SocketAddr, pub_addr: SocketAddr, ) -> Result<Self>

Registers a new Pastry node which will be available publicly on http://hostname:port

Arguments
  • config - The Pastry network configuration.
  • addr - The address of the socket to listen on.
  • pub_addr - The address the node will be exposed on.
Returns

A Result containing the newly registered node.

Examples found in repository?
examples/store/main.rs (line 16)
13    pub fn new(addr: SocketAddr, pub_addr: SocketAddr) -> Result<Self> {
14        let config = Config::new(16);
15        Ok(KVStoreNode {
16            pastry_node: PastryNode::new(config, addr, pub_addr)?,
17        })
18    }
pub async fn bootstrap_and_serve( self, bootstrap_addr: Option<&str>, ) -> Result<()>

Connects to Pastry network via bootstrap node and serves node server. Consumes node.

Arguments
  • bootstrap_addr - A bootstrap node address.
Returns

An empty Result

Examples found in repository?
examples/store/main.rs (line 23)
20    pub async fn serve(&mut self, bootstrap_addr: Option<&str>) -> Result<()> {
21        self.pastry_node
22            .clone()
23            .bootstrap_and_serve(bootstrap_addr)
24            .await
25    }
pub fn get_id(&self) -> u64

Gets the internal Pastry node ID.

pub fn get_public_address(&self) -> String

Gets the public Pastry node address.

Source

impl PastryNode

pub async fn get_kv(&self, key: &[u8]) -> Result<Option<Vec<u8>>>

Retrieves a value associated with the given key stored in the Pastry network.

Arguments
  • key - A slice of bytes representing the key for which the value is requested.
Returns

Returns a Result which is:

  • Ok(Some(Vec<u8>)) if the key exists, containing the associated value.
  • Ok(None) if the key does not exist.
  • Err(e) where e encapsulates any error encountered during the operation.
pub async fn set_kv(&self, key: &[u8], value: &[u8]) -> Result<Option<Vec<u8>>>

Sets a value for a given key in the Pastry network.

Arguments
  • key - A slice of bytes representing the key to which the value is to be associated.
  • value - A slice of bytes representing the value to be set.
Returns

Returns a Result which is:

  • Ok(Some(Vec<u8>)) if the key existed and the value was replaced, containing the old value.
  • Ok(None) if the key did not exist and a new entry was created.
  • Err(e) where e encapsulates any error encountered during the operation.
pub async fn delete_kv(&self, key: &[u8]) -> Result<Option<Vec<u8>>>

Deletes the value associated with the given key in the Pastry network.

Arguments
  • key - A slice of bytes representing the key whose associated value is to be deleted.
Returns

Returns a Result which is:

  • Ok(Some(Vec<u8>)) if the key existed and the value was successfully deleted, containing the deleted value.
  • Ok(None) if the key did not exist.
  • Err(e) where e encapsulates any error encountered during the operation.