pub struct PastryNode { /* private fields */ }Expand description
An instance of a Pastry node.
Implementations
Sourceimpl PastryNode
impl PastryNode
Sourcepub fn new(
config: Config,
addr: SocketAddr,
pub_addr: SocketAddr,
) -> Result<Self>
pub fn new( config: Config, addr: SocketAddr, pub_addr: SocketAddr, ) -> Result<Self>
Sourcepub async fn bootstrap_and_serve(
self,
bootstrap_addr: Option<&str>,
) -> Result<()>
pub async fn bootstrap_and_serve( self, bootstrap_addr: Option<&str>, ) -> Result<()>
Sourcepub fn get_public_address(&self) -> String
pub fn get_public_address(&self) -> String
Gets the public Pastry node address.
Sourceimpl PastryNode
impl PastryNode
Sourcepub async fn get_kv(&self, key: &[u8]) -> Result<Option<Vec<u8>>>
pub async fn get_kv(&self, key: &[u8]) -> Result<Option<Vec<u8>>>
Retrieves a value associated with the given key stored in the Pastry network.
Arguments
key- A slice of bytes representing the key for which the value is requested.
Returns
Returns a Result which is:
Ok(Some(Vec<u8>))if the key exists, containing the associated value.Ok(None)if the key does not exist.Err(e)whereeencapsulates any error encountered during the operation.
Sourcepub async fn set_kv(&self, key: &[u8], value: &[u8]) -> Result<Option<Vec<u8>>>
pub async fn set_kv(&self, key: &[u8], value: &[u8]) -> Result<Option<Vec<u8>>>
Sets a value for a given key in the Pastry network.
Arguments
key- A slice of bytes representing the key to which the value is to be associated.value- A slice of bytes representing the value to be set.
Returns
Returns a Result which is:
Ok(Some(Vec<u8>))if the key existed and the value was replaced, containing the old value.Ok(None)if the key did not exist and a new entry was created.Err(e)whereeencapsulates any error encountered during the operation.
Sourcepub async fn delete_kv(&self, key: &[u8]) -> Result<Option<Vec<u8>>>
pub async fn delete_kv(&self, key: &[u8]) -> Result<Option<Vec<u8>>>
Deletes the value associated with the given key in the Pastry network.
Arguments
key- A slice of bytes representing the key whose associated value is to be deleted.
Returns
Returns a Result which is:
Ok(Some(Vec<u8>))if the key existed and the value was successfully deleted, containing the deleted value.Ok(None)if the key did not exist.Err(e)whereeencapsulates any error encountered during the operation.